@@ -169,7 +169,7 @@ class Daemon(object):
         # Decouple from parent environment
         os.chdir('/')
         os.setsid()
-        os.umask(0)
+        os.umask(0o022)
 
         # Fork again
         try:
